Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(398)

Unified Diff: components/os_crypt/key_storage_util_linux.h

Issue 2948783002: Create setting that disables password stores (Closed)
Patch Set: lint Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/os_crypt/key_storage_util_linux.h
diff --git a/components/os_crypt/key_storage_util_linux.h b/components/os_crypt/key_storage_util_linux.h
index d5c04b6e70b8e8a36be3be6c1d428276704a40e4..14b045ab3fa02e97618fa63d7f74c2ae79cf8556 100644
--- a/components/os_crypt/key_storage_util_linux.h
+++ b/components/os_crypt/key_storage_util_linux.h
@@ -9,6 +9,10 @@
#include "base/nix/xdg_util.h"
+namespace base {
+class FilePath;
+}
+
namespace os_crypt {
// The supported Linux backends for storing passwords.
@@ -23,13 +27,21 @@ enum class SelectedLinuxBackend {
};
// Decide which backend to target. |type| is checked first. If it does not
// match a supported backend, |desktop_env| will be used to decide.
// TODO(crbug/571003): This is exposed as a utility only for password manager to
// use. It should be merged into key_storage_linux, once no longer needed in
// password manager.
SelectedLinuxBackend SelectBackend(const std::string& type,
+ bool use_backend,
base::nix::DesktopEnvironment desktop_env);
+// Set the setting that disables using OS-level encryption.
+bool WriteBackendUse(const base::FilePath& user_data_dir, bool use);
vabr (Chromium) 2017/07/03 19:27:14 nit: Let's be clearer about the meaning of |use|.
cfroussios 2017/07/04 09:58:15 Done.
+
+// Decide whether the backend should be used based on the setting.
+bool GetBackendUse(const base::FilePath& user_data_dir);
+
} // namespace os_crypt
#endif // COMPONENTS_OS_CRYPT_KEY_STORAGE_UTIL_LINUX_H_
@@ -23,13 +27,21 @@ enum class SelectedLinuxBackend {
};
// Decide which backend to target. |type| is checked first. If it does not
-// match a supported backend, |desktop_env| will be used to decide.
+// match a supported backend and |use_backend| is true, |desktop_env| will be
+// used to decide.
// TODO(crbug/571003): This is exposed as a utility only for password manager to
// use. It should be merged into key_storage_linux, once no longer needed in

Powered by Google App Engine
This is Rietveld 408576698